(function ($) {

  /**
   * The recommended way for producing HTML markup through JavaScript is to write
   * theming functions. These are similiar to the theming functions that you might
   * know from 'phptemplate' (the default PHP templating engine used by most
   * Drupal themes including Omega). JavaScript theme functions accept arguments
   * and can be overriden by sub-themes.
   *
   * In most cases, there is no good reason to NOT wrap your markup producing
   * JavaScript in a theme function.
   */
  Drupal.theme.prototype.wcmOmegaBaseExampleButton = function (path, title) {
    // Create an anchor element with jQuery.
    return $('<a href="' + path + '" title="' + title + '">' + title + '</a>');
  };


// End Example, Behaviors for this theme start here

  Drupal.behaviors.wcmOmegaSearchBlock = {
    attach: function (context, settings) {

      var toggleButton      = $('#search-block-toggle').eq(0);
      var searchBox         = $('#block-search-form').eq(0);
      var searchTextInput   = searchBox.find('input.form-text').eq(0);

      /**
       * The following reacts to clicks anywhere. If the click is within the
       * search box, the search box will stay visible. If the click is outside the
       * search box, the search box will be dismissed.
       */
      $(document).click(function(event) {
        toggleSearchBox(event);
      });

      toggleButton.keypress(function(event){
        if (event.which === 13) {
          toggleSearchBox(event);
        }
      });

      function toggleSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        if (clickTarget.attr('id') == toggleButton.attr('id')) {
          // Clicked the toggle button.
          if (searchBox.is(':visible') ){
            // Turn sticky visibility on.
            hideHoverSearchBox();
          }
          else {
            showHoverSearchBox();
          }
        }
        else if (clickedSearchBox(event)) {
          return;
        }
        else if (searchBox.is(':visible')) {
          // This only matters if the search box is currently visible.
          hideHoverSearchBox(true);
        }
      }

      /*
       * Determines if the target clicked was inside the search box.
       */
      function clickedSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        var inSearchBox = false;
        // Check if the search box itself was clicked.
        if (searchBox.get(0) == clickTarget.get(0)) {
          // Search box was clicked.
          inSearchBox = true;
        }
        else {
          /*
           * Compare the click target against all the elements in the search box
           * to determine if the clicked element is part of it.
           */
          var elements = searchBox.find('*');
          elements.each(function(index) {
            if (elements.eq(index).get(0) == clickTarget.get(0)) {
              // Search box element was clicked.
              inSearchBox = true;
              return;
            }
          });
        }
        return inSearchBox;
      }

      /*
       * Displays the hover search box.
       */
      function showHoverSearchBox() {
        searchBox.stop(true, true).clearQueue().fadeIn('fast');
        toggleButton.addClass('fa-search-minus');
      }

      /*
       * Hides the hover search box when applicable.
       *
       * @param force
       *   If set to TRUE, forces the search box to be hidden and disables
       *   the sticky visibility parameter.
       */
      function hideHoverSearchBox(force) {

        if (force != undefined) {
          if (force === true) {
            // Hide the box and turn sticky visibility off.
            hideHoverSearchBox_do();
            return;
          }
        }

        if (!searchBox.is(':focus')) {
          hideHoverSearchBox_do();
        }
      }

      function hideHoverSearchBox_do() {
        // Handles the actual hiding, without any logical operations.
        searchBox.stop(true, true).fadeOut('fast')
        toggleButton.removeClass('fa-search-minus');
      }
      
    }
  };


/*** MatchHeight support ***/  
  Drupal.behaviors.wcmOmegaMatchHeights = {
    attach: function (context, settings) {

      if ($.fn.matchHeight) {
        /* Match tile panes to equal height by row */
        var rows = $('.node-type-ocio-landing-page .row-tiles .row-fluid');
        rows.each(function() {
          var resize = true;

          var row = $(this);
          var regions = row.find('.tile-panel');
          regions.each(function(row){

            if ($(this).find('.fieldable-panels-pane').size() > 1 ) {
              resize = false;
              return false;
            }
          });

          if (resize) {
            var panes = row.find('.tile-panel .fieldable-panels-pane');
            panes.find('.text-areas, .title-box').matchHeight({byRow: false});
            panes.matchHeight({byRow: false});
          }
        });
      }
            
    }
  };
  

/*** If browser has no svg support, replace svg images with pngs ***/
  Drupal.behaviors.wcmOmegaSVGFallback = {
		attach: function (context, settings) {
      
      $('.no-svg img', context).each(function() {
        var src = $(this).attr('src').split('.');
        if (src.pop().toLowerCase() == 'svg') {
          src.push('png');
          $(this).attr('src', src.join('.'));
        }
      });
  		
		}
  };
  

/*** Adds/alters classes for mean-menu ***/
  Drupal.behaviors.wcmOmegaMeanMenu = {
		attach: function (context, settings) {
  		
  		$(".mean-container .mean-nav ul li span").addClass("nolink");
  		
		}
  };
  
  
/*** removes zurb responsive table classes for selected items ***/
  Drupal.behaviors.wcmOmegaExcludeZurb = {
		attach: function (context, settings) {
  		//remove for panel panes that are not full width
  		$(".panel-display .span3 table").removeClass("responsive");
      $(".panel-display .span4 table").removeClass("responsive");
  		$(".panel-display .span6 table").removeClass("responsive");
  		
  		//remove for views -- checking with moe first
		}
  };
  
  
/*** Adjustments for Media Magnet ***/
  Drupal.behaviors.wcmOmegaMediaMagnet = {
		attach: function (context, settings) {
    
      /* Move Media Magnet channel icon to title area if only one channel is selected */
      $(document).ajaxSuccess(function( event, request, settings ) {
        if (settings.url.indexOf("mediamagnet.osu.edu/api") >= 0 ) {
          $('.pane-mm-widgets-live-pane.mm-channel-type-undefined').each(function() {
            panel = $(this);
            icons = panel.find('.item i.fa');
            panel.find('.fa-fw').attr('class',function(index, classes) {
              var newClass = icons.first().attr('class').match(/fa-[^\s]+/g);
              if (newClass) {
                panel.removeClass('mm-channel-type-undefined');
                classes = classes.replace('fa-fw', newClass);
                icons.remove();
                $(this).find('.element-invisible').text(newClass);
              }
              return classes;
            });
          });
        }
      });

		}
  };
  

})(jQuery);
